//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React, { Fragment } from "react";
import SVG from "../svg";
import { Popover, Transition } from "@headlessui/react";
import { isArray, without, map, isNumber } from "lodash";
import HeaderMenuActions from "./menu-actions";
import HeaderMenuItems from "./menu-items";
import HeaderMenuPosts from "./menu-posts";
import { COLORS } from "primeobjects-helper-util";
import Link from "next/link";
export var HeaderMenuTitle = function (props) {
    var title = props.title ? props.title : "Need Title";
    var colorName = props.colorName ? props.colorName : "sky";
    var href = props.href ? props.href : "#";
    var maxWidth = isNumber(props.maxWidth) && props.maxWidth > 100 ? props.maxWidth : 400;
    var sections = isArray(props.sections) ? props.sections : [];
    var renderSections = function () {
        return without(map(sections, function (section, idx) {
            switch (section.type) {
                case "items":
                    return (isArray(section.data) && (React.createElement(HeaderMenuItems, { key: "".concat(idx), title: section.title, href: section.href, mobileView: section.mobileView, data: section.data, colorName: colorName })));
                case "actions":
                    return (isArray(section.data) && (React.createElement(HeaderMenuActions, { key: idx, title: section.title, data: section.data })));
                case "posts":
                    return (isArray(section.data) && (React.createElement(HeaderMenuPosts, { key: idx, title: section.title, data: section.data })));
                default:
                    return undefined;
            }
        }), undefined);
    };
    return !(isArray(sections) && sections.length > 0) ? (React.createElement(Link, { href: href },
        React.createElement("a", { className: "text-base text-gray-600 hover:text-gray-900" },
            React.createElement("span", null, title)))) : (React.createElement(Popover, { className: "relative" }, function (_a) {
        var open = _a.open;
        return (React.createElement(React.Fragment, null,
            React.createElement(Popover.Button, { className: "group bg-white rounded-md inline-flex items-center content-center text-base focus:outline-none\n                                ".concat(open
                    ? "text-".concat(colorName, "-700 hover:text-").concat(colorName, "-700")
                    : "text-gray-700 hover:text-gray-900") },
                React.createElement("span", { className: "font-medium" }, title),
                React.createElement(SVG, { style: { width: 12, marginLeft: 10 }, src: "/icons/platform/chevron-down-menu.svg", color: open
                        ? COLORS[colorName.toUpperCase()]["700"]
                        : COLORS.GRAY["700"], className: "".concat(open ? "flip-h" : ""), "aria-hidden": "true" })),
            React.createElement(Transition, { as: Fragment, enter: "transition ease-out duration-200", enterFrom: "opacity-0 translate-y-1", enterTo: "opacity-100 translate-y-0", leave: "transition ease-in duration-150", leaveFrom: "opacity-100 translate-y-0", leaveTo: "opacity-0 translate-y-1" },
                React.createElement(Popover.Panel, { className: "absolute -ml-4 mt-3 transform z-10 px-2 w-screen max-w-screen-xs sm:px-0 lg:ml-0 lg:left-1/2 lg:-translate-x-1/2", style: { maxWidth: maxWidth } },
                    React.createElement("div", { className: "rounded-lg shadow-lg ring-1 ring-black ring-opacity-5 overflow-hidden" }, renderSections())))));
    }));
};
export default HeaderMenuTitle;
//# sourceMappingURL=menu-title.js.map